@@ -104,7 +104,7 @@ namespace QPatternist
         {
             data = 0;
             additionalData = 0;
-            model = Q_NULLPTR;
+            model = nullptr;
         }
     };
 }
@@ -127,6 +127,8 @@ public:
     {
     }
 
+    QXmlNodeModelIndex &operator=(const QXmlNodeModelIndex &) = default;
+
     bool operator==(const QXmlNodeModelIndex &other) const;
     bool operator!=(const QXmlNodeModelIndex &other) const;
 
